.. PolyA documentation master file, created by
   sphinx-quickstart on Mon Jun  7 10:33:03 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PolyA's documentation!
=================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`



Readme
======

.. mdinclude:: ../../README.md
